@@ -36,17 +36,25 @@ class DatasetConfig(BaseModel):
         description="Whether to create unstyled views for the dataset"
     )
     apply_recipe: Optional[List[str]] = Field(
-        default=None,
+        default=[],
         description="List of recipe names to apply to the dataset"
     )
     exclude_recipe: Optional[List[str]] = Field(
-        default=None,
+        default=[],
         description="List of recipe names to exclude from the dataset"
     )
     explores_as_extensions: Optional[bool] = Field(
         default=False,
         description="Whether to create explores as extensions"
     )
+    include_descriptions: Optional[bool] = Field(
+        default=True,
+        description="Whether to create descriptions for views and fields"
+    )
+    field_types: Optional[List[str]] = Field(
+        default=None,
+        description="List of field types to include"
+    )
 
 class LoaderConfig(BaseModel):
     """Loader configuration model for Looker Loader"""
